<?php

declare(strict_types=1);

/*
 * This file is part of the Extension "sf_event_mgt" for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 */

namespace DERHANSEN\SfEventMgt\Tests\Unit\Domain\Model;

use DERHANSEN\SfEventMgt\Domain\Model\FrontendUser;
use TYPO3\CMS\Extbase\Persistence\ObjectStorage;
use TYPO3\TestingFramework\Core\Unit\UnitTestCase;

class FrontendUserTest extends UnitTestCase
{
    protected FrontendUser $subject;

    protected function setUp(): void
    {
        $this->subject = new FrontendUser();
    }

    protected function tearDown(): void
    {
        unset($this->subject);
    }

    /**
     * @test
     */
    public function getUsernameReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getUsername());
    }

    /**
     * @test
     */
    public function setUsernameSetsUsername(): void
    {
        $this->subject->setUsername('typo3');
        self::assertEquals('typo3', $this->subject->getUsername());
    }

    /**
     * @test
     */
    public function getNameReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getName());
    }

    /**
     * @test
     */
    public function setNameSetsName(): void
    {
        $this->subject->setName('Random Name');
        self::assertEquals('Random Name', $this->subject->getName());
    }

    /**
     * @test
     */
    public function getFirstNameReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getFirstName());
    }

    /**
     * @test
     */
    public function setFirstNameSetsFirstName(): void
    {
        $this->subject->setFirstName('Firstname');
        self::assertEquals('Firstname', $this->subject->getFirstName());
    }

    /**
     * @test
     */
    public function getMiddleNameReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getMiddleName());
    }

    /**
     * @test
     */
    public function setMiddleNameSetsMiddleName(): void
    {
        $this->subject->setMiddleName('Middlename');
        self::assertEquals('Middlename', $this->subject->getMiddleName());
    }

    /**
     * @test
     */
    public function getLastNameReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getLastName());
    }

    /**
     * @test
     */
    public function setLastNameSetsLastName(): void
    {
        $this->subject->setLastName('Lastname');
        self::assertEquals('Lastname', $this->subject->getLastName());
    }

    /**
     * @test
     */
    public function getAddressReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getAddress());
    }

    /**
     * @test
     */
    public function setAddressSetsAddress(): void
    {
        $this->subject->setAddress('Address');
        self::assertEquals('Address', $this->subject->getAddress());
    }

    /**
     * @test
     */
    public function getTelephoneReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getTelephone());
    }

    /**
     * @test
     */
    public function setTelephoneSetsTelephone(): void
    {
        $this->subject->setTelephone('Telephone');
        self::assertEquals('Telephone', $this->subject->getTelephone());
    }

    /**
     * @test
     */
    public function getFaxReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getFax());
    }

    /**
     * @test
     */
    public function setFaxSetsFax(): void
    {
        $this->subject->setFax('Fax');
        self::assertEquals('Fax', $this->subject->getFax());
    }

    /**
     * @test
     */
    public function getEmailReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getEmail());
    }

    /**
     * @test
     */
    public function setEmailSetsEmail(): void
    {
        $this->subject->setEmail('email');
        self::assertEquals('email', $this->subject->getEmail());
    }

    /**
     * @test
     */
    public function getTitleReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getTitle());
    }

    /**
     * @test
     */
    public function setTitleSetsTitle(): void
    {
        $this->subject->setTitle('title');
        self::assertEquals('title', $this->subject->getTitle());
    }

    /**
     * @test
     */
    public function getZipReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getZip());
    }

    /**
     * @test
     */
    public function setZipSetsZip(): void
    {
        $this->subject->setZip('12345');
        self::assertEquals('12345', $this->subject->getZip());
    }

    /**
     * @test
     */
    public function getCityReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getCity());
    }

    /**
     * @test
     */
    public function setCitySetsCity(): void
    {
        $this->subject->setCity('city');
        self::assertEquals('city', $this->subject->getCity());
    }

    /**
     * @test
     */
    public function getCountryReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getCountry());
    }

    /**
     * @test
     */
    public function setCountrySetsCountry(): void
    {
        $this->subject->setCountry('country');
        self::assertEquals('country', $this->subject->getCountry());
    }

    /**
     * @test
     */
    public function getWwwReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getWww());
    }

    /**
     * @test
     */
    public function setWwwSetsWww(): void
    {
        $this->subject->setWww('typo3.org');
        self::assertEquals('typo3.org', $this->subject->getWww());
    }

    /**
     * @test
     */
    public function getCompanyReturnsInitialValue(): void
    {
        self::assertEquals('', $this->subject->getCompany());
    }

    /**
     * @test
     */
    public function setCompanySetsCompany(): void
    {
        $this->subject->setCompany('company');
        self::assertEquals('company', $this->subject->getCompany());
    }

    /**
     * @test
     */
    public function getImageReturnsInitialValue(): void
    {
        self::assertEquals(new ObjectStorage(), $this->subject->getImage());
    }

    /**
     * @test
     */
    public function setImageSetsImage(): void
    {
        $image = new ObjectStorage();
        $this->subject->setImage($image);
        self::assertSame($image, $this->subject->getImage());
    }
}
